Crate yellowstone_shield_store

Crate yellowstone_shield_store 

Structs

MockPolicyStore
A mock implementation of PolicyStore for testing purposes.
PolicyCache
A thread-safe cache for storing policies by their associated public keys.
PolicyRpcClient
PolicyStore
A structure that manages the caching and synchronization of identity policies.
PolicyStoreBuilder
PolicyStoreConfig
PolicyStoreGrpcConfig
PolicyStoreRpcConfig
SlotCacheItem
SlotRpcResponse
Snapshot
permission strategies for specific identities.

Enums

CheckError
ShieldStoreCommitmentLevel
StoreError

Traits

PolicyStoreTrait

Type Aliases

PoliciesSlotRpcResponse
StoreResult
SubscriptionTask