pub struct PolicyCache { /* private fields */ }Expand description
A thread-safe cache for storing policies by their associated public keys.
Implementations
Sourceimpl PolicyCache
impl PolicyCache
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new, empty PolicyCache.
Returns
A new instance of PolicyCache with an empty internal storage.
Sourcepub fn insert(&self, pubkey: Pubkey, slot: u64, item: Policy)
pub fn insert(&self, pubkey: Pubkey, slot: u64, item: Policy)
Inserts a policy into the cache, associating it with the given public key. Only updates if the incoming slot is greater than the current slot.
Arguments
pubkey- The public key to associate with the policy.slot- The slot number of the policy update.policy- The policy to be stored in the cache.